#
# spec file for package screengrab
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           screengrab
Version:        2.9.0
Release:        1.1
Summary:        Qt tool for creating screenshots
License:        GPL-2.0-only
Group:          System/X11/Utilities
URL:            https://github.com/lxqt/screengrab
Source0:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz
Source1:        %{url}/releases/download/%{version}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  cmake >= 3.18.0
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  cmake(KF6WindowSystem)
BuildRequires:  cmake(Qt6LinguistTools)
BuildRequires:  pkgconfig(Qt5Xdg) >= 3.11.0
BuildRequires:  pkgconfig(Qt6Core) >= 6.6
BuildRequires:  pkgconfig(Qt6DBus)
BuildRequires:  pkgconfig(Qt6Gui)
BuildRequires:  pkgconfig(Qt6Network)
BuildRequires:  pkgconfig(Qt6Widgets)
BuildRequires:  pkgconfig(Qt6Xdg) >= 4.0.0
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(x11-xcb)
BuildRequires:  pkgconfig(xcb)
BuildRequires:  pkgconfig(xcb-shape)
BuildRequires:  pkgconfig(xcb-xfixes)
Recommends:     %{name}-lang

%description
Screenshot taker with the ability to publish them via hosting services.

%lang_package

%prep
%autosetup -p1

%build
%cmake_qt6 \
    -DSG_EXT_EDIT="1" \
    -DSG_DBUS_NOTIFY="1"
%qt6_build

%install
%qt6_install
rm -rf %{buildroot}%{_datadir}/doc

%find_lang %{name} --with-qt

%files
%license COPYING
%doc AUTHORS CHANGELOG README.md docs/html
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.??g
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{name}.conf
%{_datadir}/metainfo/%{name}.metainfo.xml

%files lang -f %{name}.lang
%dir %{_datadir}/%{name}/translations
%if 0%{?sle_version}
%{_datadir}/%{name}/translations/%{name}_???.qm
%endif

%changelog
* Mon Nov 11 2024 Shawn Dunn <sfalken@opensuse.org>
- Removed:
  * screengrab-link.patch
* Wed Nov  6 2024 Андрей Алыпов <and.november@opensuse.org>
- Update to version 2.9.0:
  * Pre-release changes (#379)
  * Updated *.ts files (#380)
  * Weblate commits (#377)
  * Weblate commits (#376)
  * Weblate commits (#372)
  * Weblate commits (#371)
  * Weblate commits (#370)
  * Fix pointer QList related memory leak
  * Properly initializes and destroys shortcuts settings
  * Weblate commits (#365)
* Thu Jul 25 2024 ming li <mli@suse.com>
- Update to 2.8.0:
  * Ported to Qt6.
* Wed Feb 21 2024 Michael Vetter <mvetter@suse.com>
- Use %%autosetup macro. Allows to eliminate the usage of deprecated
  %%patchN.
* Mon Nov  6 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 2.7.0:
  * Updated the code, made some code cleanup, and updated translations
* Sat Apr 15 2023 Shawn Dunn <sfalken@opensuse.org>
- Update to 2.6.0:
  * Updated translations and bumped the version
* Sat Nov  5 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Update to 2.5.0:
  * Fixed the screenshot of window and its decoration with multi-screen setups.
  * Removed shared libraries.
  * Removed fix-no-undefined-builderror.patch
* Sun Aug 28 2022 Shawn Dunn <sfalken@cloverleaf-linux.org>
- Add patch to correct failing build.  [gh#lxqt/screengrab#310]
  * fix-no-undefined-builderror.patch
- Cleaned up %%build section
- Modified %%files, due to new additions from upstream
* Fri Apr 29 2022 Michael Vetter <mvetter@suse.com>
- Update to 2.4.0:
  * Used an SVG icon instead of the blurry PNG icon.
  * Fixed several problems in calling external editors or default app.
  * Added metadata file.
- Use -DSG_EXT_EDIT=ON
- Add screengrab-link.patch
* Mon Nov  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.3.0:
  * Bumped minimum required Qt version to 5.15 and made a small
    fix to About dialog.
* Fri Apr 16 2021 Michael Vetter <mvetter@suse.com>
- Update to 2.2.0:
  * Code cleanup as well as translations update.
* Wed Nov  4 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.1.0:
  * Fixed screen area and window modes with scale factors > 1.
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Requires Qt5Xdg 3.5.0 or higher
* Mon Apr 27 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Changed screengrab.keyring to tsujan's key
* Sat Apr 25 2020 Callum Farmer <callumjfarmer13@gmail.com>
- Update to version 2.0.1
  * Only translations are updated.
* Tue Mar 24 2020 Max Lin <mlin@suse.com>
- Disable RPATH for building
* Thu Jan 23 2020 Michael Vetter <mvetter@suse.com>
- Update to 2.0.0:
  * Improved translations
  * Improved user experience (less noise with command line, better
    screen area instructions and better off-screen screenshots).
  * Code update and clean-up, including the removal of the
    deprecated class QDesktopWidget.
  * Bumped screengrab version to 2.0.0
  * Updated translations
  * Removed Qxt
  * Fixed typo in function name
  * Set min. Qt version to 5.10.0
  * Removed upload module (#183)
  * Removed QDesktopWidget
  * Removed (duplicated) string casts definitions
  * Deleted useless warning fixes #174
  * Make CMakeLists.txt a bit more strict
  * Updated QtXdg minimum required version
  * Use the new QtXdg XdgMimeApps class
  * Improved Screen Area instructions (#162)
  * Don't use automatic string conversions
  * Avoid char raw strings literals memory allocations
* Fri Mar  1 2019 mvetter@suse.com
- Update to 1.101:
  * Only translations was changed
* Thu Jan 31 2019 Michael Vetter <mvetter@suse.com>
- Update to 1.100:
  * Don’t crash with invalid config format
* Mon Jul 23 2018 mvetter@suse.com
- Update to 1.99:
  * Update translations
  * Add X11Extras and Network to link target
- Remove screengrab-1.98-build.patch: upstreamed
* Tue May 22 2018 mvetter@suse.com
- Require Qt >= 5.7.1
- Rename build.patch to screengrab-1.98-build.patch
- Add new default config file screengrab.conf
* Tue May 22 2018 adam.majer@suse.de
- cleanup cmake build
- build.patch: add missing requirements
* Tue May 22 2018 mvetter@suse.com
- Update to 1.98:
  * Update translations
  * A more specific condition for Ctrl+C
  * Filter out Ctrl+C in Delay box
  * No window screenshot with shaded windows
  * Always use contents rect Fixes https://github.com/lxqt/screengrab/issues/67
  * Never scale up beyond real size
  * Several fixes, especially for the tray icon
  * __DATE__ and __TIME__ macro are not very helpful for reproducible builds.
  * Added a minimum default configuration
  * Handle invalid window screenshots
  * Corrected a grammar mistake
  * Always use native (LXQt) file dialog
  * Just changed the location of a comment
  * Cleanup and fixes
  * Some ui polishing
  * Improve screengrab app behaviour
  * Drops Qt foreach
  * fix some uris
  * Update references in about dialog
* Sun May 20 2018 mvetter@suse.com
- Cleanup with spec-cleaner
- Adjust URL and tarball link
- Rename screengrab-keyring.gpg to screengrab.keyring
- Dont require gpg-offline, let OBS do checking
- Remove icon cache update statements
* Sat Feb 10 2018 and.november@opensuse.org
- run spec-cleaner
* Sat Feb 10 2018 and.november@opensuse.org
- build with Qt5
